Learn R Programming

nandb (version 0.2.1)

KmerTIFFsFromBrightnessCSVs: Create kmer tiff files from brightness csvs

Description

For each brightness csv image in a folder, given a monomeric brightness, create a tiff file of the kmer positions using KmerArray().

Usage

KmerTIFFsFromBrightnessCSVs(monomer, csv.paths = NULL, out.names = NULL,
  na = "saturate", mcc = parallel::detectCores(), verbose = TRUE)

Arguments

monomer

The (median) brightness of a monomer.

csv.paths

The paths to the brightness csv files, defaults to list.files(pattern = '[Bb]rightness.*\.csv').

out.names

The names you want the output files to have (will be forced to .tif).

mcc

The number of parallel cores to use for the processing.

verbose

Do you want to print a message when the function is done?

Examples

Run this code
# NOT RUN {
img <- system.file('extdata', '50.tif', package = 'nandb')
setwd(tempdir())
file.copy(img, ".")
BrightnessTxtFolder()
KmerTIFFsFromBrightnessCSVs(1.111)
file.remove(list.files())  # cleanup

# }

Run the code above in your browser using DataLab